@@ -1,12 +1,12 @@
 package App::ListOrgTodos;
 
-our $DATE = '2016-12-24'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use Log::Any::IfLOG qw($log);
+use Log::ger;
 
 use App::ListOrgHeadlines qw(list_org_headlines);
 use Perinci::Sub::Util qw(gen_modified_sub);
@@ -55,7 +55,7 @@ App::ListOrgTodos - List all todo items in all Org files
 
 =head1 VERSION
 
-This document describes version 0.45 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2016-12-24.
+This document describes version 0.46 of App::ListOrgTodos (from Perl distribution App-OrgUtils), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -66,7 +66,11 @@ This document describes version 0.45 of App::ListOrgTodos (from Perl distributio
 =head1 FUNCTIONS
 
 
-=head2 list_org_todos(%args) -> [status, msg, result, meta]
+=head2 list_org_todos
+
+Usage:
+
+ list_org_todos(%args) -> [status, msg, result, meta]
 
 List all todo items in all Org files.
 
@@ -211,7 +215,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
@@ -227,7 +231,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
